@@ -5,6 +5,7 @@ import os
 import shutil
 
 import onnx
+from onnx.external_data_helper import load_external_data_for_model
 import tensorflow as tf
 from tensorflow.core.framework import graph_pb2
 from tensorflow.python.tools import freeze_graph
@@ -92,8 +93,11 @@ def parse_args(args):
 
   # required two args, source and destination path
   parser.add_argument("--infile", "-i", help="Input file path.", required=True)
-  parser.add_argument(
-      "--outdir", "-o", help="Output directory.", required=True)
+  parser.add_argument("--outdir", "-o", help="Output directory.", required=True)
+  parser.add_argument("--extdatadir",
+                      "-e",
+                      help="External input data file directory.",
+                      required=False)
 
   def add_argument_group(parser, group_name, funcs):
     group = parser.add_argument_group(group_name)
@@ -126,11 +130,19 @@ def convert(infile, outdir, **kwargs):
     None.
   """
   logging_level = kwargs.get("logging_level", "INFO")
+  ext_data_dir = kwargs.get("extdatadir")
+
   common.logger.setLevel(logging_level)
   common.logger.handlers[0].setLevel(logging_level)
+  common.logger.info("Start converting onnx pb to tf saved model")
+
+  # load external data if the file directory is provided
+  if ext_data_dir:
+    onnx_model = onnx.load(infile, load_external_data=False)
+    load_external_data_for_model(onnx_model, ext_data_dir)
+  else:
+    onnx_model = onnx.load(infile)
 
-  common.logger.info("Start converting onnx pb to tf pb:")
-  onnx_model = onnx.load(infile)
   tf_rep = backend.prepare(onnx_model, **kwargs)
   tf_rep.export_graph(outdir)
   common.logger.info("Converting completes successfully.")
