@@ -6,12 +6,12 @@ from onnx_tf.handlers.handler import tf_func
 from onnx_tf.handlers.handler import partial_support
 from onnx_tf.handlers.handler import ps_description
 
-
 @onnx_op("Cast")
 @tf_func(tf.cast)
 @partial_support(True)
-@ps_description("Cast string to float32/float64/int32/int64 " +
-                "are not supported in Tensorflow.")
+@ps_description("Cast string to data types other than " +
+                "float32/float64/int32/int64 is not supported in Tensorflow")
+
 class Cast(BackendHandler):
 
   @classmethod
@@ -19,15 +19,7 @@ class Cast(BackendHandler):
     return {"rename": {"to": "dtype"}}
 
   @classmethod
-  def version_1(cls, node, **kwargs):
-    return [cls.make_tensor_from_onnx_node(node, **kwargs)]
-
-  @classmethod
-  def version_6(cls, node, **kwargs):
-    return [cls.make_tensor_from_onnx_node(node, **kwargs)]
-
-  @classmethod
-  def version_9(cls, node, **kwargs):
+  def _common(cls, node, **kwargs):
     inp = kwargs["tensor_dict"][node.inputs[0]]
     to_type = node.attrs.get("to")
 
@@ -42,3 +34,20 @@ class Cast(BackendHandler):
       return [tf.strings.to_number(inp, to_type)]
 
     return [cls.make_tensor_from_onnx_node(node, **kwargs)]
+
+  @classmethod
+  def version_1(cls, node, **kwargs):
+    return [cls.make_tensor_from_onnx_node(node, **kwargs)]
+
+  @classmethod
+  def version_6(cls, node, **kwargs):
+    return [cls.make_tensor_from_onnx_node(node, **kwargs)]
+
+  @classmethod
+  def version_9(cls, node, **kwargs):
+    return cls._common(node, **kwargs)
+
+  @classmethod
+  def version_13(cls, node, **kwargs):
+    return cls._common(node, **kwargs)
+
