@@ -18,9 +18,17 @@ class Identity(BackendHandler):
     return [cls.make_tensor_from_onnx_node(node, **kwargs)]
 
   @classmethod
-  def version_14(cls, node, **kwargs):
+  def _common(cls, node, **kwargs):
     x = kwargs["tensor_dict"][node.inputs[0]]
     if isinstance(x, (list, tuple)):
       return [tf.identity_n(x)]
     else:
       return [tf.identity(x)]
+
+  @classmethod
+  def version_14(cls, node, **kwargs):
+    return cls._common(node, **kwargs)
+
+  @classmethod
+  def version_16(cls, node, **kwargs):
+    return cls._common(node, **kwargs)
