@@ -6,6 +6,14 @@ from .scan_mixin import ScanMixin
 @onnx_op("Scan")
 class Scan(ScanMixin, BackendHandler):
 
+  @classmethod
+  def get_initializer_from_subgraph(cls, node, init_dict, callback_func):
+    return callback_func(node.attrs["body"], init_dict)
+
+  @classmethod
+  def create_variables(cls, handlers, node, init_dict, var_dict, callback_func):
+    return callback_func(handlers, node.attrs["body"], init_dict, var_dict)
+
   @classmethod
   def _common(cls, node, **kwargs):
     return cls.scan(node, kwargs["tensor_dict"], kwargs.get("strict", True))
