@@ -14,15 +14,16 @@ class Slice(BackendHandler):
     tensor_dict = kwargs["tensor_dict"]
     x = tensor_dict[node.inputs[0]]
 
-    full_sizes = tf.shape(x)
+    # Shape output as int64 since the spec implicitly allows int64
+    full_sizes = tf.shape(x, out_type=tf.int64)
 
     starts = node.attrs.get("starts")
     ends = node.attrs.get("ends")
     slice_len = len(starts)
     axes = node.attrs.get("axes", list(range(slice_len)))
 
-    updated_full_sizes = [0] * len(full_sizes)
-    updated_full_begin = [0] * len(full_sizes)
+    updated_full_sizes = [0] * len(x.get_shape())
+    updated_full_begin = [0] * len(x.get_shape())
     updated_starts = [0] * slice_len
     updated_ends = [0] * slice_len
 
